=======
Compute
=======

This section describes configuring nova hypervisors and
compute services like HyperV, XenServer and so on.

.. toctree::
   :maxdepth: 1

   hyperv-guide
   nova-fake-driver
   vmware-guide
   xenserver-guide
   zun-guide
